@@ -55,6 +55,11 @@ def testrunner(options, args):
     if CP.has_option(section, 'dsn'):
         options.dsn = CP.get(section, 'dsn')
 
+    if CP.has_option(section, 'sender-address')
+        options.sender_address = CP.get(section, 'sender-address'
+    else:
+        options.sender_address = 'no-reply@foo.org'
+
     options.coverage = False
     if CP.has_option(section, 'coverage'):
         options.coverage = CP.getboolean(section, 'coverage')
@@ -156,7 +161,7 @@ def testrunner(options, args):
         from email.MIMEText import MIMEText
 
         outer = MIMEMultipart()
-        outer['From'] = 'ep-testrunner-no-reply@haufe.de'
+        outer['From'] = options.sender_address
         outer['To'] = recipients
         outer['Subject'] = subject
         outer['Content-Type'] = 'text/plain; charset=iso-8859-15'
